/*++

Copyright (c) 2012-2016 ELMOS Co., Ltd.

Module Name:
	RAIxx.h
Abstract:
	RAI-12/RAI-16 API library definitions
Revision History:
	12/08/23	Created.
	13/05/01	Support for Windows 8.
	14/05/19	Fixed bug.
	14/06/13	Added RAI_GetAnalogVoltageEx.
	14/06/13	Added RAI_GetAnalogVoltageExEx.
	16/04/12	SamplingRate upper limit released.

--*/

#ifndef RAIxx_H
#define RAIxx_H

#ifdef RAI_EXPORTS_
#define RAI_API __declspec(dllexport)
#else
#define RAI_API __declspec(dllimport)
#endif

//
// Device status (Return Value)
//
enum {
    RAI_OK,
    RAI_INVALID_ID,
    RAI_DEVICE_NOT_FOUND,
    RAI_DEVICE_NOT_OPENED,
	RAI_OTHER_ERROR,
	RAI_COMMUNICATION_ERROR,
	RAI_INVALID_PARAMETER,
	RAI_MEMORY_ERROR
};

//
// Constants
//
#define	RAI_SAMPLING_RATE_10KSPS	1
#define	RAI_SAMPLING_RATE_1KSPS		10
#define	RAI_SAMPLING_RATE_100SPS	100
#define	RAI_SAMPLING_RATE_10SPS		1000

#define	RAI_TRIGGER_CH0	0x00
#define	RAI_TRIGGER_CH1	0x01
#define	RAI_TRIGGER_CH2	0x02
#define	RAI_TRIGGER_CH3	0x03

#define	RAI_TRIGGER_TYPE_LEVEL_H		0x00
#define	RAI_TRIGGER_TYPE_LEVEL_L		0x01
#define	RAI_TRIGGER_TYPE_SLOPE_RISING	0x02
#define	RAI_TRIGGER_TYPE_SLOPE_FALLING	0x03


#ifdef __cplusplus
extern "C" {
#endif

//
// Function definitions
//
RAI_API int WINAPI RAI_GetNumberOfDevices (int *Number);
RAI_API int WINAPI RAI_GetSerialNumber (int Index, int *SerialNumber);
RAI_API int WINAPI RAI_Open (BYTE *ID);
RAI_API int WINAPI RAI_OpenBySerialNumber (int SerialNumber, BYTE *ID);
RAI_API int WINAPI RAI_Close (BYTE ID);
RAI_API int WINAPI RAI_GetAnalogVoltage (BYTE ID, double *CH0Value, double *CH1Value, double *CH2Value, double *CH3Value, int SamplingCount);
RAI_API int WINAPI RAI_GetAnalogVoltageEx (BYTE ID, double *CH0Value, double *CH1Value, double *CH2Value, double *CH3Value, int SamplingRate, int SamplingCount);
RAI_API int WINAPI RAI_GetAnalogVoltageExEx (BYTE ID, double *CH0Value, double *CH1Value, double *CH2Value, double *CH3Value, int SamplingRate, int SamplingCount, int *ReadCount, BYTE TriggerCH, BYTE TriggerType, double TriggerThreshold, int TriggerWaitCount);

#ifdef __cplusplus
}
#endif

#endif  /* RAIxx_H */
